# Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
# or more contributor license agreements. See the NOTICE file distributed with
# this work for additional information regarding copyright
# ownership. Elasticsearch B.V. licenses this file to you under
# the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import logging

from opentelemetry import trace

from opentelemetry.sdk.trace.sampling import ParentBasedTraceIdRatio
from opentelemetry._opamp import messages
from opentelemetry._opamp.agent import OpAMPAgent
from opentelemetry._opamp.client import OpAMPClient
from opentelemetry._opamp.proto import opamp_pb2 as opamp_pb2


logger = logging.getLogger(__name__)

_LOG_LEVELS_MAP = {
    "trace": 5,
    "debug": logging.DEBUG,
    "info": logging.INFO,
    "warn": logging.WARNING,
    "error": logging.ERROR,
    "fatal": logging.CRITICAL,
    "off": 1000,
}

DEFAULT_SAMPLING_RATE = 1.0


def _handle_logging_level(config) -> str:
    error_message = ""
    # when config option has default value you don't get it so need to handle the default
    config_logging_level = config.get("logging_level")
    if config_logging_level is not None:
        logging_level = _LOG_LEVELS_MAP.get(config_logging_level)  # type: ignore[reportArgumentType]
    else:
        logging_level = logging.INFO

    if logging_level is None:
        logger.error("Logging level not handled: %s", config_logging_level)
        error_message = f"Logging level not handled: {config_logging_level}"
    else:
        # update upstream and distro logging levels
        logging.getLogger("opentelemetry").setLevel(logging_level)
        logging.getLogger("elasticotel").setLevel(logging_level)
    return error_message


def _handle_sampling_rate(config) -> str:
    config_sampling_rate = config.get("sampling_rate")
    sampling_rate = DEFAULT_SAMPLING_RATE
    if config_sampling_rate is not None:
        try:
            sampling_rate = float(config_sampling_rate)
            if sampling_rate < 0 or sampling_rate > 1.0:
                raise ValueError()
        except ValueError:
            logger.error("Invalid `sampling_rate` from config `%s`", config_sampling_rate)
            return f"Invalid sampling_rate {config_sampling_rate}"

    sampler = getattr(trace.get_tracer_provider(), "sampler", None)
    if sampler is None:
        logger.debug("Cannot get sampler from tracer provider.")
        return ""

    # FIXME: this needs to be updated for the consistent probability samplers
    if not isinstance(sampler, ParentBasedTraceIdRatio):
        logger.warning("Sampler %s is not supported, not applying sampling_rate.", type(sampler))
        return ""

    # since sampler is parent based we need to update its root sampler
    root_sampler = sampler._root  # type: ignore[reportAttributeAccessIssue]
    if root_sampler.rate != sampling_rate:  # type: ignore[reportAttributeAccessIssue]
        # we don't have a proper way to update it :)
        root_sampler._rate = sampling_rate  # type: ignore[reportAttributeAccessIssue]
        root_sampler._bound = root_sampler.get_bound_for_rate(root_sampler._rate)  # type: ignore[reportAttributeAccessIssue]
        logger.debug("Updated sampler rate to %s", sampling_rate)
    return ""


def opamp_handler(agent: OpAMPAgent, client: OpAMPClient, message: opamp_pb2.ServerToAgent):
    # we check config_hash because we need to track last received config and remote_config seems to be always truthy
    if not message.remote_config or not message.remote_config.config_hash:
        return

    error_messages = []
    for config_filename, config in messages._decode_remote_config(message.remote_config):
        # we don't have standardized config values so limit to configs coming from our backend
        if config_filename == "elastic":
            logger.debug("Config %s: %s", config_filename, config)
            error_message = _handle_logging_level(config)
            if error_message:
                error_messages.append(error_message)

            error_message = _handle_sampling_rate(config)
            if error_message:
                error_messages.append(error_message)

    error_message = "\n".join(error_messages)
    status = opamp_pb2.RemoteConfigStatuses_FAILED if error_message else opamp_pb2.RemoteConfigStatuses_APPLIED
    updated_remote_config = client._update_remote_config_status(
        remote_config_hash=message.remote_config.config_hash, status=status, error_message=error_message
    )
    # if we changed the config send an ack to the server so we don't receive the same config at every heartbeat response
    if updated_remote_config is not None:
        payload = client._build_remote_config_status_response_message(updated_remote_config)
        agent.send(payload=payload)



# Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
# or more contributor license agreements. See the NOTICE file distributed with
# this work for additional information regarding copyright
# ownership. Elasticsearch B.V. licenses this file to you under
# the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from opentelemetry.instrumentation.bootstrap import run as orig_run
from opentelemetry.instrumentation.bootstrap_gen import (
    default_instrumentations as gen_default_instrumentations,
)
from opentelemetry.instrumentation.bootstrap_gen import (
    libraries as gen_libraries,
)
from packaging.requirements import Requirement


# the instrumentations available in opentelemetry-bootstrap we want to skip
_EXCLUDED_INSTRUMENTATIONS = {"opentelemetry-instrumentation-openai-v2"}

# update with:
# $ python3.12 scripts/build_edot_bootstrap_instrumentations.py | ruff format -
_EDOT_INSTRUMENTATIONS = [
    {
        "library": "openai >= 1.2.0",
        "instrumentation": "elastic-opentelemetry-instrumentation-openai",
    }
]


def _get_instrumentation_name(library_entry):
    instrumentation = library_entry["instrumentation"]
    instrumentation_name = Requirement(instrumentation)
    return instrumentation_name.name


def run() -> None:
    """This is a tiny wrapper around the upstream opentelemetry-boostrap implementation that let us decide which instrumentation to use"""
    libraries = [
        lib for lib in gen_libraries if _get_instrumentation_name(lib) not in _EXCLUDED_INSTRUMENTATIONS
    ] + _EDOT_INSTRUMENTATIONS
    return orig_run(default_instrumentations=gen_default_instrumentations, libraries=libraries)



# Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
# or more contributor license agreements. See the NOTICE file distributed with
# this work for additional information regarding copyright
# ownership. Elasticsearch B.V. licenses this file to you under
# the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import annotations

import atexit
import logging
import queue
import random
import threading
from typing import Any, Callable

from opentelemetry._opamp.client import OpAMPClient
from opentelemetry._opamp.proto import opamp_pb2 as opamp_pb2

logger = logging.getLogger(__name__)


class _Job:
    """
    Represents a single request job, with retry/backoff metadata.
    """

    def __init__(
        self,
        payload: Any,
        max_retries: int = 1,
        initial_backoff: float = 1.0,
        callback: Callable[..., None] | None = None,
    ):
        self.payload = payload
        self.attempt = 0
        self.max_retries = max_retries
        self.initial_backoff = initial_backoff
        # callback is called after OpAMP message handler is executed
        self.callback = callback

    def should_retry(self) -> bool:
        """Checks if we should retry again"""
        return self.attempt <= self.max_retries

    def delay(self) -> float:
        """Calculate the delay before next retry"""
        assert self.attempt > 0
        return self.initial_backoff * (2 ** (self.attempt - 1)) * random.uniform(0.8, 1.2)


class OpAMPAgent:
    """
    OpAMPAgent handles:
      - periodic “heartbeat” calls enqueued at a fixed interval
      - on-demand calls via send()
      - exponential backoff retry on failures
      - immediate cancellation of all jobs on shutdown
    """

    def __init__(
        self,
        *,
        interval: float,
        message_handler: Callable[["OpAMPAgent", OpAMPClient, opamp_pb2.ServerToAgent], None],
        max_retries: int = 10,
        heartbeat_max_retries: int = 1,
        initial_backoff: float = 1.0,
        client: OpAMPClient,
    ):
        """
        :param interval: seconds between automatic calls
        :param message_handler: user provided function that takes the received ServerToAgent message
        :param max_retries: how many times to retry a failed job for ad-hoc messages
        :param heartbeat_max_retries: how many times to retry an heartbeat failed job
        :param initial_backoff: base seconds for exponential backoff
        :param client: an OpAMPClient instance
        """
        self._interval = interval
        self._handler = message_handler
        self._max_retries = max_retries
        self._heartbeat_max_retries = heartbeat_max_retries
        self._initial_backoff = initial_backoff

        self._queue: queue.Queue[_Job] = queue.Queue()
        self._stop = threading.Event()

        self._worker = threading.Thread(name="OpAMPAgentWorker", target=self._run_worker, daemon=True)
        self._scheduler = threading.Thread(name="OpAMPAgentScheduler", target=self._run_scheduler, daemon=True)
        # start scheduling only after connection with server has been established
        self._schedule = False

        self._client = client

    def _enable_scheduler(self):
        self._schedule = True
        logger.debug("Connected with endpoint, enabling heartbeat")

    def start(self) -> None:
        """
        Starts the scheduler and worker threads.
        """
        self._stop.clear()
        self._worker.start()
        self._scheduler.start()

        atexit.register(self.stop)

        # enqueue the connection message so we can then enable heartbeat
        payload = self._client._build_connection_message()
        self.send(payload, max_retries=self._max_retries, callback=self._enable_scheduler)

    def send(self, payload: Any, max_retries: int | None = None, callback: Callable[..., None] | None = None) -> None:
        """
        Enqueue an on-demand request.
        """
        if not self._worker.is_alive():
            logger.warning("Called send() but worker thread is not alive. Worker threads is started with start()")

        if max_retries is None:
            max_retries = self._max_retries
        job = _Job(payload, max_retries=max_retries, initial_backoff=self._initial_backoff, callback=callback)
        self._queue.put(job)
        logger.debug("On-demand job enqueued: %r", payload)

    def _run_scheduler(self) -> None:
        """
        After me made a connection periodically enqueue “heartbeat” jobs until stop is signaled.
        """
        while not self._stop.wait(self._interval):
            if self._schedule:
                payload = self._client._build_heartbeat_message()
                job = _Job(
                    payload=payload, max_retries=self._heartbeat_max_retries, initial_backoff=self._initial_backoff
                )
                self._queue.put(job)
                logger.debug("Periodic job enqueued")

    def _run_worker(self) -> None:
        """
        Worker loop: pull jobs, attempt the message handler, retry on failure with backoff.
        """
        while not self._stop.is_set():
            try:
                job: _Job = self._queue.get(timeout=1)
            except queue.Empty:
                continue

            message = None
            while job.should_retry() and not self._stop.is_set():
                try:
                    message = self._client._send(job.payload)
                    logger.debug("Job succeeded: %r", job.payload)
                    break
                except Exception as exc:
                    job.attempt += 1
                    logger.warning("Job %r failed attempt %d/%d: %s", job.payload, job.attempt, job.max_retries, exc)

                    if not job.should_retry():
                        logger.error("Job %r dropped after max retries", job.payload)
                        logger.exception(exc)
                        break

                    # exponential backoff with +/- 20% jitter, interruptible by stop event
                    delay = job.delay()
                    logger.debug("Retrying in %.1fs", delay)
                    if self._stop.wait(delay):
                        # stop requested during backoff: abandon job
                        logger.debug("Stop signaled, abandoning job %r", job.payload)
                        break

            if message is not None:
                # we can't do much if the handler fails other than logging
                try:
                    self._handler(self, self._client, message)
                    logger.debug("Called Job message handler for: %r", message)
                except Exception as exc:
                    logger.warning("Job %r handler failed with: %s", job.payload, exc)

            try:
                if job.callback is not None:
                    job.callback()
            except Exception as exc:
                logging.warning("Callback for job failed: %s", exc)
            finally:
                self._queue.task_done()

    def stop(self) -> None:
        """
        Immediately cancel all in-flight and queued jobs, then join threads.
        """

        # Before exiting send signal the server we are disconnecting to free our resources
        # This is not required by the spec but is helpful in practice
        logger.debug("Stopping OpAMPClient: sending AgentDisconnect")
        payload = self._client._build_agent_disconnect_message()
        try:
            self._client._send(payload)
        except Exception:
            logger.debug("Stopping OpAMPClient: failed to send AgentDisconnect message")

        logger.debug("Stopping OpAMPClient: cancelling jobs")
        # Clear pending jobs
        while True:
            try:
                self._queue.get_nowait()
                self._queue.task_done()
            except queue.Empty:
                break

        # Signal threads to exit
        self._stop.set()
        # don't crash if the user calls stop() before start() or calls stop() multiple times
        try:
            self._worker.join()
        except RuntimeError as exc:
            logger.warning("Stopping OpAMPClient: worker thread failed to join %s", exc)
        try:
            self._scheduler.join()
        except RuntimeError as exc:
            logger.warning("Stopping OpAMPClient: scheduler thread failed to join %s", exc)
        logger.debug("OpAMPClient stopped")



# Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
# or more contributor license agreements. See the NOTICE file distributed with
# this work for additional information regarding copyright
# ownership. Elasticsearch B.V. licenses this file to you under
# the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import logging
import os
from urllib.parse import urlparse, urlunparse

from opentelemetry.environment_variables import (
    OTEL_LOGS_EXPORTER,
    OTEL_METRICS_EXPORTER,
    OTEL_TRACES_EXPORTER,
)
from opentelemetry.exporter.otlp.proto.grpc import _USER_AGENT_HEADER_VALUE
from opentelemetry.exporter.otlp.proto.grpc._log_exporter import OTLPLogExporter as GRPCOTLPLogExporter
from opentelemetry.exporter.otlp.proto.grpc.metric_exporter import OTLPMetricExporter as GRPCOTLPMetricExporter
from opentelemetry.exporter.otlp.proto.grpc.trace_exporter import OTLPSpanExporter as GRPCOTLPSpanExporter
from opentelemetry.exporter.otlp.proto.http import _OTLP_HTTP_HEADERS
from opentelemetry.exporter.otlp.proto.http._log_exporter import OTLPLogExporter as HTTPOTLPLogExporter
from opentelemetry.exporter.otlp.proto.http.metric_exporter import OTLPMetricExporter as HTTPOTLPMetricExporter
from opentelemetry.exporter.otlp.proto.http.trace_exporter import OTLPSpanExporter as HTTPOTLPSpanExporter
from opentelemetry.instrumentation.distro import BaseDistro
from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
from opentelemetry.instrumentation.system_metrics import (
    _DEFAULT_CONFIG as SYSTEM_METRICS_DEFAULT_CONFIG,
    SystemMetricsInstrumentor,
)
from opentelemetry.sdk._configuration import _OTelSDKConfigurator
from opentelemetry.sdk.environment_variables import (
    OTEL_METRICS_EXEMPLAR_FILTER,
    OTEL_EXPERIMENTAL_RESOURCE_DETECTORS,
    OTEL_EXPORTER_OTLP_METRICS_TEMPORALITY_PREFERENCE,
    OTEL_EXPORTER_OTLP_PROTOCOL,
    OTEL_TRACES_SAMPLER,
    OTEL_TRACES_SAMPLER_ARG,
)
from opentelemetry.sdk.resources import OTELResourceDetector
from opentelemetry.util._importlib_metadata import EntryPoint
from opentelemetry._opamp.agent import OpAMPAgent
from opentelemetry._opamp.client import OpAMPClient
from opentelemetry._opamp.proto import opamp_pb2 as opamp_pb2

from elasticotel.distro import version
from elasticotel.distro.environment_variables import ELASTIC_OTEL_OPAMP_ENDPOINT, ELASTIC_OTEL_SYSTEM_METRICS_ENABLED
from elasticotel.distro.resource_detectors import get_cloud_resource_detectors
from elasticotel.distro.config import opamp_handler, DEFAULT_SAMPLING_RATE


logger = logging.getLogger(__name__)

EDOT_GRPC_USER_AGENT_HEADER_VALUE = "elastic-otlp-grpc-python/" + version.__version__
EDOT_HTTP_USER_AGENT_HEADER_VALUE = "elastic-otlp-http-python/" + version.__version__


class ElasticOpenTelemetryConfigurator(_OTelSDKConfigurator):
    def _configure(self, **kwargs):
        # override GRPC and HTTP user agent headers, GRPC works since OTel SDK 1.35.0, HTTP currently requires an hack
        otlp_grpc_exporter_options = {
            "channel_options": (
                ("grpc.primary_user_agent", f"{EDOT_GRPC_USER_AGENT_HEADER_VALUE} {_USER_AGENT_HEADER_VALUE}"),
            )
        }
        otlp_http_exporter_options = {
            "headers": {
                **_OTLP_HTTP_HEADERS,
                "User-Agent": f"{EDOT_HTTP_USER_AGENT_HEADER_VALUE} {_OTLP_HTTP_HEADERS['User-Agent']}",
            }
        }
        kwargs["exporter_args_map"] = {
            GRPCOTLPLogExporter: otlp_grpc_exporter_options,
            GRPCOTLPMetricExporter: otlp_grpc_exporter_options,
            GRPCOTLPSpanExporter: otlp_grpc_exporter_options,
            HTTPOTLPLogExporter: otlp_http_exporter_options,
            HTTPOTLPMetricExporter: otlp_http_exporter_options,
            HTTPOTLPSpanExporter: otlp_http_exporter_options,
        }
        # TODO: Remove the following line after rebasing on top of upstream 1.37.0
        _OTLP_HTTP_HEADERS["User-Agent"] = otlp_http_exporter_options["headers"]["User-Agent"]

        super()._configure(**kwargs)

        enable_opamp = False
        endpoint = os.environ.get(ELASTIC_OTEL_OPAMP_ENDPOINT)
        if endpoint:
            parsed = urlparse(endpoint)
            enable_opamp = parsed.scheme in ("http", "https") and parsed.netloc
            if enable_opamp:
                if not parsed.path:
                    parsed = parsed._replace(path="/v1/opamp")

                endpoint_url = urlunparse(parsed)
                # this is not great but we don't have the calculated resource attributes around
                resource = OTELResourceDetector().detect()
                agent_identifying_attributes = {
                    "service.name": resource.attributes.get("service.name"),
                }
                if deployment_environment_name := resource.attributes.get(
                    "deployment.environment.name", resource.attributes.get("deployment.environment")
                ):
                    agent_identifying_attributes["deployment.environment.name"] = deployment_environment_name

                opamp_client = OpAMPClient(
                    endpoint=endpoint_url,
                    agent_identifying_attributes=agent_identifying_attributes,
                )
                opamp_agent = OpAMPAgent(
                    interval=30,
                    message_handler=opamp_handler,
                    client=opamp_client,
                )
                opamp_agent.start()
            else:
                logger.warning("Found invalid value for OpAMP endpoint")


class ElasticOpenTelemetryDistro(BaseDistro):
    def load_instrumentor(self, entry_point: EntryPoint, **kwargs):
        # When running in the k8s operator loading of an instrumentor may fail because the environment
        # in which python extensions are built does not match the one from the running container but
        # ImportErrors raised here are handled by the autoinstrumentation code
        instrumentor_class: BaseInstrumentor = entry_point.load()

        instrumentor_kwargs = {}
        if instrumentor_class == SystemMetricsInstrumentor:
            system_metrics_configuration = os.environ.get(ELASTIC_OTEL_SYSTEM_METRICS_ENABLED, "false")
            system_metrics_enabled = system_metrics_configuration.lower() == "true"
            if not system_metrics_enabled:
                instrumentor_kwargs["config"] = {
                    k: v for k, v in SYSTEM_METRICS_DEFAULT_CONFIG.items() if k.startswith("process.runtime")
                }
        instrumentor_class(**instrumentor_kwargs).instrument(**kwargs)  # type: ignore[reportCallIssue]

    def _configure(self, **kwargs):
        os.environ.setdefault(OTEL_TRACES_EXPORTER, "otlp")
        os.environ.setdefault(OTEL_METRICS_EXPORTER, "otlp")
        os.environ.setdefault(OTEL_LOGS_EXPORTER, "otlp")
        os.environ.setdefault(OTEL_EXPORTER_OTLP_PROTOCOL, "grpc")
        # disable exemplars by default for now
        os.environ.setdefault(OTEL_METRICS_EXEMPLAR_FILTER, "always_off")
        # preference to use DELTA temporality as we can handle only this kind of Histograms
        os.environ.setdefault(OTEL_EXPORTER_OTLP_METRICS_TEMPORALITY_PREFERENCE, "DELTA")
        os.environ.setdefault(OTEL_TRACES_SAMPLER, "parentbased_traceidratio")
        os.environ.setdefault(OTEL_TRACES_SAMPLER_ARG, str(DEFAULT_SAMPLING_RATE))

        base_resource_detectors = [
            "process_runtime",
            "os",
            "otel",
            "telemetry_distro",
            "service_instance",
            "containerid",
        ]
        detectors = base_resource_detectors + get_cloud_resource_detectors()
        os.environ.setdefault(OTEL_EXPERIMENTAL_RESOURCE_DETECTORS, ",".join(detectors))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opamp.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import anyvalue_pb2 as anyvalue__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bopamp.proto\x12\x0bopamp.proto\x1a\x0e\x61nyvalue.proto\"\xae\x05\n\rAgentToServer\x12\x14\n\x0cinstance_uid\x18\x01 \x01(\x0c\x12\x14\n\x0csequence_num\x18\x02 \x01(\x04\x12\x38\n\x11\x61gent_description\x18\x03 \x01(\x0b\x32\x1d.opamp.proto.AgentDescription\x12\x14\n\x0c\x63\x61pabilities\x18\x04 \x01(\x04\x12,\n\x06health\x18\x05 \x01(\x0b\x32\x1c.opamp.proto.ComponentHealth\x12\x36\n\x10\x65\x66\x66\x65\x63tive_config\x18\x06 \x01(\x0b\x32\x1c.opamp.proto.EffectiveConfig\x12=\n\x14remote_config_status\x18\x07 \x01(\x0b\x32\x1f.opamp.proto.RemoteConfigStatus\x12\x36\n\x10package_statuses\x18\x08 \x01(\x0b\x32\x1c.opamp.proto.PackageStatuses\x12\x36\n\x10\x61gent_disconnect\x18\t \x01(\x0b\x32\x1c.opamp.proto.AgentDisconnect\x12\r\n\x05\x66lags\x18\n \x01(\x04\x12K\n\x1b\x63onnection_settings_request\x18\x0b \x01(\x0b\x32&.opamp.proto.ConnectionSettingsRequest\x12<\n\x13\x63ustom_capabilities\x18\x0c \x01(\x0b\x32\x1f.opamp.proto.CustomCapabilities\x12\x32\n\x0e\x63ustom_message\x18\r \x01(\x0b\x32\x1a.opamp.proto.CustomMessage\x12>\n\x14\x61vailable_components\x18\x0e \x01(\x0b\x32 .opamp.proto.AvailableComponents\"\x11\n\x0f\x41gentDisconnect\"W\n\x19\x43onnectionSettingsRequest\x12:\n\x05opamp\x18\x01 \x01(\x0b\x32+.opamp.proto.OpAMPConnectionSettingsRequest\"^\n\x1eOpAMPConnectionSettingsRequest\x12<\n\x13\x63\x65rtificate_request\x18\x01 \x01(\x0b\x32\x1f.opamp.proto.CertificateRequest\"!\n\x12\x43\x65rtificateRequest\x12\x0b\n\x03\x63sr\x18\x01 \x01(\x0c\"\xbb\x01\n\x13\x41vailableComponents\x12\x44\n\ncomponents\x18\x01 \x03(\x0b\x32\x30.opamp.proto.AvailableComponents.ComponentsEntry\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\x1aP\n\x0f\x43omponentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.opamp.proto.ComponentDetails:\x02\x38\x01\"\xe1\x01\n\x10\x43omponentDetails\x12\'\n\x08metadata\x18\x01 \x03(\x0b\x32\x15.opamp.proto.KeyValue\x12M\n\x11sub_component_map\x18\x02 \x03(\x0b\x32\x32.opamp.proto.ComponentDetails.SubComponentMapEntry\x1aU\n\x14SubComponentMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.opamp.proto.ComponentDetails:\x02\x38\x01\"\xa1\x04\n\rServerToAgent\x12\x14\n\x0cinstance_uid\x18\x01 \x01(\x0c\x12\x38\n\x0e\x65rror_response\x18\x02 \x01(\x0b\x32 .opamp.proto.ServerErrorResponse\x12\x35\n\rremote_config\x18\x03 \x01(\x0b\x32\x1e.opamp.proto.AgentRemoteConfig\x12\x42\n\x13\x63onnection_settings\x18\x04 \x01(\x0b\x32%.opamp.proto.ConnectionSettingsOffers\x12:\n\x12packages_available\x18\x05 \x01(\x0b\x32\x1e.opamp.proto.PackagesAvailable\x12\r\n\x05\x66lags\x18\x06 \x01(\x04\x12\x14\n\x0c\x63\x61pabilities\x18\x07 \x01(\x04\x12>\n\x14\x61gent_identification\x18\x08 \x01(\x0b\x32 .opamp.proto.AgentIdentification\x12\x32\n\x07\x63ommand\x18\t \x01(\x0b\x32!.opamp.proto.ServerToAgentCommand\x12<\n\x13\x63ustom_capabilities\x18\n \x01(\x0b\x32\x1f.opamp.proto.CustomCapabilities\x12\x32\n\x0e\x63ustom_message\x18\x0b \x01(\x0b\x32\x1a.opamp.proto.CustomMessage\"\xb4\x01\n\x17OpAMPConnectionSettings\x12\x1c\n\x14\x64\x65stination_endpoint\x18\x01 \x01(\t\x12%\n\x07headers\x18\x02 \x01(\x0b\x32\x14.opamp.proto.Headers\x12\x30\n\x0b\x63\x65rtificate\x18\x03 \x01(\x0b\x32\x1b.opamp.proto.TLSCertificate\x12\"\n\x1aheartbeat_interval_seconds\x18\x04 \x01(\x04\"\x94\x01\n\x1bTelemetryConnectionSettings\x12\x1c\n\x14\x64\x65stination_endpoint\x18\x01 \x01(\t\x12%\n\x07headers\x18\x02 \x01(\x0b\x32\x14.opamp.proto.Headers\x12\x30\n\x0b\x63\x65rtificate\x18\x03 \x01(\x0b\x32\x1b.opamp.proto.TLSCertificate\"\x97\x02\n\x17OtherConnectionSettings\x12\x1c\n\x14\x64\x65stination_endpoint\x18\x01 \x01(\t\x12%\n\x07headers\x18\x02 \x01(\x0b\x32\x14.opamp.proto.Headers\x12\x30\n\x0b\x63\x65rtificate\x18\x03 \x01(\x0b\x32\x1b.opamp.proto.TLSCertificate\x12O\n\x0eother_settings\x18\x04 \x03(\x0b\x32\x37.opamp.proto.OtherConnectionSettings.OtherSettingsEntry\x1a\x34\n\x12OtherSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\x07Headers\x12$\n\x07headers\x18\x01 \x03(\x0b\x32\x13.opamp.proto.Header\"$\n\x06Header\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"D\n\x0eTLSCertificate\x12\x0c\n\x04\x63\x65rt\x18\x01 \x01(\x0c\x12\x13\n\x0bprivate_key\x18\x02 \x01(\x0c\x12\x0f\n\x07\x63\x61_cert\x18\x03 \x01(\x0c\"\xcd\x03\n\x18\x43onnectionSettingsOffers\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x33\n\x05opamp\x18\x02 \x01(\x0b\x32$.opamp.proto.OpAMPConnectionSettings\x12=\n\x0bown_metrics\x18\x03 \x01(\x0b\x32(.opamp.proto.TelemetryConnectionSettings\x12<\n\nown_traces\x18\x04 \x01(\x0b\x32(.opamp.proto.TelemetryConnectionSettings\x12:\n\x08own_logs\x18\x05 \x01(\x0b\x32(.opamp.proto.TelemetryConnectionSettings\x12V\n\x11other_connections\x18\x06 \x03(\x0b\x32;.opamp.proto.ConnectionSettingsOffers.OtherConnectionsEntry\x1a]\n\x15OtherConnectionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.opamp.proto.OtherConnectionSettings:\x02\x38\x01\"\xbe\x01\n\x11PackagesAvailable\x12>\n\x08packages\x18\x01 \x03(\x0b\x32,.opamp.proto.PackagesAvailable.PackagesEntry\x12\x19\n\x11\x61ll_packages_hash\x18\x02 \x01(\x0c\x1aN\n\rPackagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.opamp.proto.PackageAvailable:\x02\x38\x01\"\x86\x01\n\x10PackageAvailable\x12&\n\x04type\x18\x01 \x01(\x0e\x32\x18.opamp.proto.PackageType\x12\x0f\n\x07version\x18\x02 \x01(\t\x12+\n\x04\x66ile\x18\x03 \x01(\x0b\x32\x1d.opamp.proto.DownloadableFile\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\"x\n\x10\x44ownloadableFile\x12\x14\n\x0c\x64ownload_url\x18\x01 \x01(\t\x12\x14\n\x0c\x63ontent_hash\x18\x02 \x01(\x0c\x12\x11\n\tsignature\x18\x03 \x01(\x0c\x12%\n\x07headers\x18\x04 \x01(\x0b\x32\x14.opamp.proto.Headers\"\x99\x01\n\x13ServerErrorResponse\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32$.opamp.proto.ServerErrorResponseType\x12\x15\n\rerror_message\x18\x02 \x01(\t\x12,\n\nretry_info\x18\x03 \x01(\x0b\x32\x16.opamp.proto.RetryInfoH\x00\x42\t\n\x07\x44\x65tails\",\n\tRetryInfo\x12\x1f\n\x17retry_after_nanoseconds\x18\x01 \x01(\x04\">\n\x14ServerToAgentCommand\x12&\n\x04type\x18\x01 \x01(\x0e\x32\x18.opamp.proto.CommandType\"\x84\x01\n\x10\x41gentDescription\x12\x35\n\x16identifying_attributes\x18\x01 \x03(\x0b\x32\x15.opamp.proto.KeyValue\x12\x39\n\x1anon_identifying_attributes\x18\x02 \x03(\x0b\x32\x15.opamp.proto.KeyValue\"\xb0\x02\n\x0f\x43omponentHealth\x12\x0f\n\x07healthy\x18\x01 \x01(\x08\x12\x1c\n\x14start_time_unix_nano\x18\x02 \x01(\x06\x12\x12\n\nlast_error\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x1d\n\x15status_time_unix_nano\x18\x05 \x01(\x06\x12R\n\x14\x63omponent_health_map\x18\x06 \x03(\x0b\x32\x34.opamp.proto.ComponentHealth.ComponentHealthMapEntry\x1aW\n\x17\x43omponentHealthMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.opamp.proto.ComponentHealth:\x02\x38\x01\"B\n\x0f\x45\x66\x66\x65\x63tiveConfig\x12/\n\nconfig_map\x18\x01 \x01(\x0b\x32\x1b.opamp.proto.AgentConfigMap\"\x7f\n\x12RemoteConfigStatus\x12\x1f\n\x17last_remote_config_hash\x18\x01 \x01(\x0c\x12\x31\n\x06status\x18\x02 \x01(\x0e\x32!.opamp.proto.RemoteConfigStatuses\x12\x15\n\rerror_message\x18\x03 \x01(\t\"\xde\x01\n\x0fPackageStatuses\x12<\n\x08packages\x18\x01 \x03(\x0b\x32*.opamp.proto.PackageStatuses.PackagesEntry\x12)\n!server_provided_all_packages_hash\x18\x02 \x01(\x0c\x12\x15\n\rerror_message\x18\x03 \x01(\t\x1aK\n\rPackagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.opamp.proto.PackageStatus:\x02\x38\x01\"\x93\x02\n\rPackageStatus\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x11\x61gent_has_version\x18\x02 \x01(\t\x12\x16\n\x0e\x61gent_has_hash\x18\x03 \x01(\x0c\x12\x1e\n\x16server_offered_version\x18\x04 \x01(\t\x12\x1b\n\x13server_offered_hash\x18\x05 \x01(\x0c\x12.\n\x06status\x18\x06 \x01(\x0e\x32\x1e.opamp.proto.PackageStatusEnum\x12\x15\n\rerror_message\x18\x07 \x01(\t\x12=\n\x10\x64ownload_details\x18\x08 \x01(\x0b\x32#.opamp.proto.PackageDownloadDetails\"U\n\x16PackageDownloadDetails\x12\x18\n\x10\x64ownload_percent\x18\x01 \x01(\x01\x12!\n\x19\x64ownload_bytes_per_second\x18\x02 \x01(\x01\"/\n\x13\x41gentIdentification\x12\x18\n\x10new_instance_uid\x18\x01 \x01(\x0c\"U\n\x11\x41gentRemoteConfig\x12+\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1b.opamp.proto.AgentConfigMap\x12\x13\n\x0b\x63onfig_hash\x18\x02 \x01(\x0c\"\xa0\x01\n\x0e\x41gentConfigMap\x12>\n\nconfig_map\x18\x01 \x03(\x0b\x32*.opamp.proto.AgentConfigMap.ConfigMapEntry\x1aN\n\x0e\x43onfigMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.opamp.proto.AgentConfigFile:\x02\x38\x01\"5\n\x0f\x41gentConfigFile\x12\x0c\n\x04\x62ody\x18\x01 \x01(\x0c\x12\x14\n\x0c\x63ontent_type\x18\x02 \x01(\t\"*\n\x12\x43ustomCapabilities\x12\x14\n\x0c\x63\x61pabilities\x18\x01 \x03(\t\"?\n\rCustomMessage\x12\x12\n\ncapability\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c*c\n\x12\x41gentToServerFlags\x12\"\n\x1e\x41gentToServerFlags_Unspecified\x10\x00\x12)\n%AgentToServerFlags_RequestInstanceUid\x10\x01*\x92\x01\n\x12ServerToAgentFlags\x12\"\n\x1eServerToAgentFlags_Unspecified\x10\x00\x12&\n\"ServerToAgentFlags_ReportFullState\x10\x01\x12\x30\n,ServerToAgentFlags_ReportAvailableComponents\x10\x02*\xf7\x02\n\x12ServerCapabilities\x12\"\n\x1eServerCapabilities_Unspecified\x10\x00\x12$\n ServerCapabilities_AcceptsStatus\x10\x01\x12)\n%ServerCapabilities_OffersRemoteConfig\x10\x02\x12-\n)ServerCapabilities_AcceptsEffectiveConfig\x10\x04\x12%\n!ServerCapabilities_OffersPackages\x10\x08\x12,\n(ServerCapabilities_AcceptsPackagesStatus\x10\x10\x12/\n+ServerCapabilities_OffersConnectionSettings\x10 \x12\x37\n3ServerCapabilities_AcceptsConnectionSettingsRequest\x10@*>\n\x0bPackageType\x12\x18\n\x14PackageType_TopLevel\x10\x00\x12\x15\n\x11PackageType_Addon\x10\x01*\x8f\x01\n\x17ServerErrorResponseType\x12#\n\x1fServerErrorResponseType_Unknown\x10\x00\x12&\n\"ServerErrorResponseType_BadRequest\x10\x01\x12\'\n#ServerErrorResponseType_Unavailable\x10\x02*&\n\x0b\x43ommandType\x12\x17\n\x13\x43ommandType_Restart\x10\x00*\xcc\x05\n\x11\x41gentCapabilities\x12!\n\x1d\x41gentCapabilities_Unspecified\x10\x00\x12#\n\x1f\x41gentCapabilities_ReportsStatus\x10\x01\x12)\n%AgentCapabilities_AcceptsRemoteConfig\x10\x02\x12,\n(AgentCapabilities_ReportsEffectiveConfig\x10\x04\x12%\n!AgentCapabilities_AcceptsPackages\x10\x08\x12,\n(AgentCapabilities_ReportsPackageStatuses\x10\x10\x12&\n\"AgentCapabilities_ReportsOwnTraces\x10 \x12\'\n#AgentCapabilities_ReportsOwnMetrics\x10@\x12%\n AgentCapabilities_ReportsOwnLogs\x10\x80\x01\x12\x35\n0AgentCapabilities_AcceptsOpAMPConnectionSettings\x10\x80\x02\x12\x35\n0AgentCapabilities_AcceptsOtherConnectionSettings\x10\x80\x04\x12,\n\'AgentCapabilities_AcceptsRestartCommand\x10\x80\x08\x12$\n\x1f\x41gentCapabilities_ReportsHealth\x10\x80\x10\x12*\n%AgentCapabilities_ReportsRemoteConfig\x10\x80 \x12\'\n\"AgentCapabilities_ReportsHeartbeat\x10\x80@\x12\x32\n,AgentCapabilities_ReportsAvailableComponents\x10\x80\x80\x01*\x9c\x01\n\x14RemoteConfigStatuses\x12\x1e\n\x1aRemoteConfigStatuses_UNSET\x10\x00\x12 \n\x1cRemoteConfigStatuses_APPLIED\x10\x01\x12!\n\x1dRemoteConfigStatuses_APPLYING\x10\x02\x12\x1f\n\x1bRemoteConfigStatuses_FAILED\x10\x03*\xc4\x01\n\x11PackageStatusEnum\x12\x1f\n\x1bPackageStatusEnum_Installed\x10\x00\x12$\n PackageStatusEnum_InstallPending\x10\x01\x12 \n\x1cPackageStatusEnum_Installing\x10\x02\x12#\n\x1fPackageStatusEnum_InstallFailed\x10\x03\x12!\n\x1dPackageStatusEnum_Downloading\x10\x04\x42.Z,github.com/open-telemetry/opamp-go/protobufsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opamp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z,github.com/open-telemetry/opamp-go/protobufs'
  _globals['_AVAILABLECOMPONENTS_COMPONENTSENTRY']._loaded_options = None
  _globals['_AVAILABLECOMPONENTS_COMPONENTSENTRY']._serialized_options = b'8\001'
  _globals['_COMPONENTDETAILS_SUBCOMPONENTMAPENTRY']._loaded_options = None
  _globals['_COMPONENTDETAILS_SUBCOMPONENTMAPENTRY']._serialized_options = b'8\001'
  _globals['_OTHERCONNECTIONSETTINGS_OTHERSETTINGSENTRY']._loaded_options = None
  _globals['_OTHERCONNECTIONSETTINGS_OTHERSETTINGSENTRY']._serialized_options = b'8\001'
  _globals['_CONNECTIONSETTINGSOFFERS_OTHERCONNECTIONSENTRY']._loaded_options = None
  _globals['_CONNECTIONSETTINGSOFFERS_OTHERCONNECTIONSENTRY']._serialized_options = b'8\001'
  _globals['_PACKAGESAVAILABLE_PACKAGESENTRY']._loaded_options = None
  _globals['_PACKAGESAVAILABLE_PACKAGESENTRY']._serialized_options = b'8\001'
  _globals['_COMPONENTHEALTH_COMPONENTHEALTHMAPENTRY']._loaded_options = None
  _globals['_COMPONENTHEALTH_COMPONENTHEALTHMAPENTRY']._serialized_options = b'8\001'
  _globals['_PACKAGESTATUSES_PACKAGESENTRY']._loaded_options = None
  _globals['_PACKAGESTATUSES_PACKAGESENTRY']._serialized_options = b'8\001'
  _globals['_AGENTCONFIGMAP_CONFIGMAPENTRY']._loaded_options = None
  _globals['_AGENTCONFIGMAP_CONFIGMAPENTRY']._serialized_options = b'8\001'
  _globals['_AGENTTOSERVERFLAGS']._serialized_start=5585
  _globals['_AGENTTOSERVERFLAGS']._serialized_end=5684
  _globals['_SERVERTOAGENTFLAGS']._serialized_start=5687
  _globals['_SERVERTOAGENTFLAGS']._serialized_end=5833
  _globals['_SERVERCAPABILITIES']._serialized_start=5836
  _globals['_SERVERCAPABILITIES']._serialized_end=6211
  _globals['_PACKAGETYPE']._serialized_start=6213
  _globals['_PACKAGETYPE']._serialized_end=6275
  _globals['_SERVERERRORRESPONSETYPE']._serialized_start=6278
  _globals['_SERVERERRORRESPONSETYPE']._serialized_end=6421
  _globals['_COMMANDTYPE']._serialized_start=6423
  _globals['_COMMANDTYPE']._serialized_end=6461
  _globals['_AGENTCAPABILITIES']._serialized_start=6464
  _globals['_AGENTCAPABILITIES']._serialized_end=7180
  _globals['_REMOTECONFIGSTATUSES']._serialized_start=7183
  _globals['_REMOTECONFIGSTATUSES']._serialized_end=7339
  _globals['_PACKAGESTATUSENUM']._serialized_start=7342
  _globals['_PACKAGESTATUSENUM']._serialized_end=7538
  _globals['_AGENTTOSERVER']._serialized_start=45
  _globals['_AGENTTOSERVER']._serialized_end=731
  _globals['_AGENTDISCONNECT']._serialized_start=733
  _globals['_AGENTDISCONNECT']._serialized_end=750
  _globals['_CONNECTIONSETTINGSREQUEST']._serialized_start=752
  _globals['_CONNECTIONSETTINGSREQUEST']._serialized_end=839
  _globals['_OPAMPCONNECTIONSETTINGSREQUEST']._serialized_start=841
  _globals['_OPAMPCONNECTIONSETTINGSREQUEST']._serialized_end=935
  _globals['_CERTIFICATEREQUEST']._serialized_start=937
  _globals['_CERTIFICATEREQUEST']._serialized_end=970
  _globals['_AVAILABLECOMPONENTS']._serialized_start=973
  _globals['_AVAILABLECOMPONENTS']._serialized_end=1160
  _globals['_AVAILABLECOMPONENTS_COMPONENTSENTRY']._serialized_start=1080
  _globals['_AVAILABLECOMPONENTS_COMPONENTSENTRY']._serialized_end=1160
  _globals['_COMPONENTDETAILS']._serialized_start=1163
  _globals['_COMPONENTDETAILS']._serialized_end=1388
  _globals['_COMPONENTDETAILS_SUBCOMPONENTMAPENTRY']._serialized_start=1303
  _globals['_COMPONENTDETAILS_SUBCOMPONENTMAPENTRY']._serialized_end=1388
  _globals['_SERVERTOAGENT']._serialized_start=1391
  _globals['_SERVERTOAGENT']._serialized_end=1936
  _globals['_OPAMPCONNECTIONSETTINGS']._serialized_start=1939
  _globals['_OPAMPCONNECTIONSETTINGS']._serialized_end=2119
  _globals['_TELEMETRYCONNECTIONSETTINGS']._serialized_start=2122
  _globals['_TELEMETRYCONNECTIONSETTINGS']._serialized_end=2270
  _globals['_OTHERCONNECTIONSETTINGS']._serialized_start=2273
  _globals['_OTHERCONNECTIONSETTINGS']._serialized_end=2552
  _globals['_OTHERCONNECTIONSETTINGS_OTHERSETTINGSENTRY']._serialized_start=2500
  _globals['_OTHERCONNECTIONSETTINGS_OTHERSETTINGSENTRY']._serialized_end=2552
  _globals['_HEADERS']._serialized_start=2554
  _globals['_HEADERS']._serialized_end=2601
  _globals['_HEADER']._serialized_start=2603
  _globals['_HEADER']._serialized_end=2639
  _globals['_TLSCERTIFICATE']._serialized_start=2641
  _globals['_TLSCERTIFICATE']._serialized_end=2709
  _globals['_CONNECTIONSETTINGSOFFERS']._serialized_start=2712
  _globals['_CONNECTIONSETTINGSOFFERS']._serialized_end=3173
  _globals['_CONNECTIONSETTINGSOFFERS_OTHERCONNECTIONSENTRY']._serialized_start=3080
  _globals['_CONNECTIONSETTINGSOFFERS_OTHERCONNECTIONSENTRY']._serialized_end=3173
  _globals['_PACKAGESAVAILABLE']._serialized_start=3176
  _globals['_PACKAGESAVAILABLE']._serialized_end=3366
  _globals['_PACKAGESAVAILABLE_PACKAGESENTRY']._serialized_start=3288
  _globals['_PACKAGESAVAILABLE_PACKAGESENTRY']._serialized_end=3366
  _globals['_PACKAGEAVAILABLE']._serialized_start=3369
  _globals['_PACKAGEAVAILABLE']._serialized_end=3503
  _globals['_DOWNLOADABLEFILE']._serialized_start=3505
  _globals['_DOWNLOADABLEFILE']._serialized_end=3625
  _globals['_SERVERERRORRESPONSE']._serialized_start=3628
  _globals['_SERVERERRORRESPONSE']._serialized_end=3781
  _globals['_RETRYINFO']._serialized_start=3783
  _globals['_RETRYINFO']._serialized_end=3827
  _globals['_SERVERTOAGENTCOMMAND']._serialized_start=3829
  _globals['_SERVERTOAGENTCOMMAND']._serialized_end=3891
  _globals['_AGENTDESCRIPTION']._serialized_start=3894
  _globals['_AGENTDESCRIPTION']._serialized_end=4026
  _globals['_COMPONENTHEALTH']._serialized_start=4029
  _globals['_COMPONENTHEALTH']._serialized_end=4333
  _globals['_COMPONENTHEALTH_COMPONENTHEALTHMAPENTRY']._serialized_start=4246
  _globals['_COMPONENTHEALTH_COMPONENTHEALTHMAPENTRY']._serialized_end=4333
  _globals['_EFFECTIVECONFIG']._serialized_start=4335
  _globals['_EFFECTIVECONFIG']._serialized_end=4401
  _globals['_REMOTECONFIGSTATUS']._serialized_start=4403
  _globals['_REMOTECONFIGSTATUS']._serialized_end=4530
  _globals['_PACKAGESTATUSES']._serialized_start=4533
  _globals['_PACKAGESTATUSES']._serialized_end=4755
  _globals['_PACKAGESTATUSES_PACKAGESENTRY']._serialized_start=4680
  _globals['_PACKAGESTATUSES_PACKAGESENTRY']._serialized_end=4755
  _globals['_PACKAGESTATUS']._serialized_start=4758
  _globals['_PACKAGESTATUS']._serialized_end=5033
  _globals['_PACKAGEDOWNLOADDETAILS']._serialized_start=5035
  _globals['_PACKAGEDOWNLOADDETAILS']._serialized_end=5120
  _globals['_AGENTIDENTIFICATION']._serialized_start=5122
  _globals['_AGENTIDENTIFICATION']._serialized_end=5169
  _globals['_AGENTREMOTECONFIG']._serialized_start=5171
  _globals['_AGENTREMOTECONFIG']._serialized_end=5256
  _globals['_AGENTCONFIGMAP']._serialized_start=5259
  _globals['_AGENTCONFIGMAP']._serialized_end=5419
  _globals['_AGENTCONFIGMAP_CONFIGMAPENTRY']._serialized_start=5341
  _globals['_AGENTCONFIGMAP_CONFIGMAPENTRY']._serialized_end=5419
  _globals['_AGENTCONFIGFILE']._serialized_start=5421
  _globals['_AGENTCONFIGFILE']._serialized_end=5474
  _globals['_CUSTOMCAPABILITIES']._serialized_start=5476
  _globals['_CUSTOMCAPABILITIES']._serialized_end=5518
  _globals['_CUSTOMMESSAGE']._serialized_start=5520
  _globals['_CUSTOMMESSAGE']._serialized_end=5583
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: anyvalue.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x61nyvalue.proto\x12\x0bopamp.proto\"\xe8\x01\n\x08\x41nyValue\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x12\x14\n\nbool_value\x18\x02 \x01(\x08H\x00\x12\x13\n\tint_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x04 \x01(\x01H\x00\x12.\n\x0b\x61rray_value\x18\x05 \x01(\x0b\x32\x17.opamp.proto.ArrayValueH\x00\x12\x31\n\x0ckvlist_value\x18\x06 \x01(\x0b\x32\x19.opamp.proto.KeyValueListH\x00\x12\x15\n\x0b\x62ytes_value\x18\x07 \x01(\x0cH\x00\x42\x07\n\x05value\"3\n\nArrayValue\x12%\n\x06values\x18\x01 \x03(\x0b\x32\x15.opamp.proto.AnyValue\"5\n\x0cKeyValueList\x12%\n\x06values\x18\x01 \x03(\x0b\x32\x15.opamp.proto.KeyValue\"=\n\x08KeyValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.opamp.proto.AnyValueB.Z,github.com/open-telemetry/opamp-go/protobufsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'anyvalue_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z,github.com/open-telemetry/opamp-go/protobufs'
  _globals['_ANYVALUE']._serialized_start=32
  _globals['_ANYVALUE']._serialized_end=264
  _globals['_ARRAYVALUE']._serialized_start=266
  _globals['_ARRAYVALUE']._serialized_end=317
  _globals['_KEYVALUELIST']._serialized_start=319
  _globals['_KEYVALUELIST']._serialized_end=372
  _globals['_KEYVALUE']._serialized_start=374
  _globals['_KEYVALUE']._serialized_end=435
# @@protoc_insertion_point(module_scope)
